<?php

namespace Drupal\social_graphql\Plugin\Deriver\Facebook\Fields;

use Drupal\social_graphql\Plugin\Deriver\SocialGraphQLPostDeriverBase;
use Drupal\graphql\Utility\StringHelper;

/**
 * Derives content entity fields as GraphQL fields.
 */
class SocialGraphQLFacebookPostFieldsDeriver extends SocialGraphQLPostDeriverBase {

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($basePluginDefinition) {

    // @todo find mapping into facebook api.
    $fields = $this->getFieldMapping();

    $this->generateDeriver($fields, $basePluginDefinition);

    return parent::getDerivativeDefinitions($basePluginDefinition);
  }


  /**
   * {@inheritdoc}
   */
  public function getFieldMapping() {
    $field = [
      'created_at',
      'id',
      'text',
      'truncated',
      'source',
      'geo',
      'coordinates',
      'place',
      'contributors',
      'is_quote_status',
      'retweet_count',
      'favorite_count',
      'favorited',
      'retweeted',
      'lang',
    ];
    $field = array_combine($field, $field);
    $field['user'] = 'SocialGraphQLFacebookUser';
    return $field;
  }

  /**
   * {@inheritdoc}
   */
  public function generateDeriver(array $fields, $basePluginDefinition) {

    foreach ($fields as $field_name => $field) {
      $type = 'String';
      $derived_id = 'social_graphql.facebook.post:';
      if ($field_name != $field) {
        $type = $field;
        $derived_id = 'social_graphql.facebook.post.user:';
      }
      $derived_id .= $field_name;
      $this->derivatives[$derived_id] = [
        'name' => StringHelper::propCase($field_name),
        'type' => $type,
        'parents' => ['SocialGraphQLFacebookPost'],
        'field_name' => $field_name,
      ] + $basePluginDefinition;
    }
  }

}
