<?php

namespace Drupal\social_graphql\Plugin\Deriver\Facebook\Fields;

use Drupal\social_graphql\Plugin\Deriver\SocialGraphQLPostDeriverBase;
use Drupal\graphql\Utility\StringHelper;

/**
 * Derives content entity fields as GraphQL fields.
 */
class SocialGraphQLFacebookUserFieldsDeriver extends SocialGraphQLPostDeriverBase {


  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($basePluginDefinition) {

    //@todo find mapping into facebook api.

    $fields = $this->getFieldMapping();

    $this->generateDeriver($fields, $basePluginDefinition);

    return parent::getDerivativeDefinitions($basePluginDefinition);
  }

  /**
   * {@inheritdoc}
   */
  public function getFieldMapping() {
    $field = [
      'id',
      'name',
      'screen_name',
      'location',
      'description',
      'url',
      'protected',
      'followers_count',
      'friends_count',
      'listed_count',
      'created_at',
      'favorites_count',
      'utc_offset',
      'time_zone',
      'geo_enabled',
      'verified',
      'statuses_count',
      'lang',
      'contributors_enabled',
      'is_translator',
      'is_translation_enabled',
      'profile_background_color',
      'profile_background_image_url',
      'profile_background_image_url_https',
      'profile_background_tile',
      'profile_image_url',
      'profile_image_url_https',
      'profile_image_url_https',
      'profile_link_color',
      'profile_sidebar_border_color',
      'profile_sidebar_fill_color',
      'profile_text_color',
      'profile_use_background_image',
      'has_extended_profile',
      'default_profile',
      'default_profile_image',
      'following',
      'follow_request_sent',
      'notifications',
      'translator_type',
    ];

    $field = array_combine($field, $field);
    return $field;
  }

  /**
   * {@inheritdoc}
   */
  public function generateDeriver(array $fields, $basePluginDefinition) {

    foreach ($fields as $field_name => $field) {
      $derived_id = 'social_graphql.facebook.post.user:' . $field_name;
      $this->derivatives[$derived_id] = [
        'name' => StringHelper::propCase($field_name),
        'type' => 'String',
        'parents' => ['SocialGraphQLFacebookUser'],
        'field_name' => $field_name,
      ] + $basePluginDefinition;
    }

  }

}
